<?php
/**
 * Philia API Accounts Route
 * A REST API route to retrieve accounts in Philia
 * 
 * @package Philia
 * @subpackage Philia_API\Rest_Routes
 */

namespace Philia_API;

if (!defined('ABSPATH')) {
    exit;
}

class Philia_Accounts_REST_Controller extends \WP_REST_Controller {

    /**
     * Registers the routes for retrieving cashier fields and handling login.
     */
    public function register_routes() {
        register_rest_route('philia/v1', '/accounts/user/notes', [
            'methods' => 'GET',
            'callback' => [$this, 'get_user_notes'],
            'permission_callback' => ['Philia_API\Philia_Cashier_REST_Controller', 'permissions_check'],
        ]);
    }

    /**
     * Retrieves a list of user notes.
     *
     * @param WP_REST_Request $request The incoming REST request.
     * @return WP_REST_Response The list of user notes or an error response.
     */
    public function get_user_notes(\WP_REST_Request $request) {
        
        $user_id = $request->get_param('user_id');

        if( empty( $user_id ) )
            return new \WP_REST_Response(['error' => 'User ID is a required field.'], 400);

        // get rewards list from philia api
        $response = Philia_Core_API::send_request('integration/accounts/user/notes/?user_id=' . $user_id , 'GET', [], 2);

        if ( is_wp_error( $response ) )
        {
            Philia_API_Log::error("Error in 'integration/accounts/user/notes/' for User Notes List - User ID: " . $user_id );
        }
        else
        {
            $api_result = json_decode( wp_remote_retrieve_body( $response, true ) , true );
            return new \WP_REST_Response( $api_result , wp_remote_retrieve_response_code( $response ) );
        }
    }
}

/**
 * Registers the Philia cashier REST controller.
 */
function register_philia_accounts_rest_controller() {
    $controller = new Philia_Accounts_REST_Controller();
    $controller->register_routes();
}

add_action('rest_api_init', 'Philia_API\register_philia_accounts_rest_controller');