<?php
/**
 * Philia API Synchronization
 * Manages user, product, and order synchronization through WordPress Admin.
 *
 * Package: Philia
 * Author: Philia
 * Last Modified Time: 2025/03/03 16:10:35
 * License: MIT
 */

namespace Philia_API;

class Philia_API_Synchronization {
    
    /**
     * Holds the singleton instance of the Philia_API_Synchronization class.
     *
     * @var Philia_API_Synchronization|null
     */
    protected static $_instance = null;

    /**
     * Singleton instance of the Philia_API_Synchronization class.
     * Ensures that only one instance exists at any given time.
     *
     * @return Philia_API_Synchronization|null Returns the singleton instance.
     */
    public static function instance() {
        if (is_null(self::$_instance)) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }

    /**
     * Constructor: adds actions to initialize synchronization page and handle AJAX.
     */
    public function __construct() {
        
        // schedule and syncing
        add_filter('cron_schedules', array($this, 'add_custom_cron_schedule'));
        //add_action('philia_sync_data', array(&$this, 'sync_data') );

        // Schedule the user sync event
        // if (!wp_next_scheduled('philia_sync_data')) {
        //     wp_schedule_event(time(), 'every_two_minutes', 'philia_sync_data');
        // }

    }

    function create_and_send_woocommerce_api_key($philia_url, $philia_key)
    {
        if (!class_exists('WooCommerce')) {
            return;
        }

        $user_id = get_current_user_id();
        $description = 'sync';
        $permissions = 'read_write';

        $consumer_key = 'ck_' . wc_rand_hash();
        $consumer_secret = 'cs_' . wc_rand_hash();

        $data = [
            'user_id'       => $user_id,
            'description'   => $description,
            'permissions'   => $permissions,
            'consumer_key'  => $consumer_key,
            'consumer_secret' => $consumer_secret,
        ];

        $api_key = wc_api_create_key($data);

        if (!isset($api_key['key_id'])) {
            return;
        }

        // Dynamically detect WooCommerce API version
        $version = defined('WC_API_REQUEST_VERSION') ? WC_API_REQUEST_VERSION : 'v3';

        $body = json_encode([
            'philia_url' => $philia_url,
            'philia_key' => $philia_key,
            'url'        => get_site_url(),
            'key'        => $consumer_key,
            'secret'     => $consumer_secret,
            'type'       => 'woocommerce',
            'version'    => $version
        ]);

        return wp_remote_post('http://hook.philia.vip/api/register', [
            'method'    => 'POST',
            'body'      => $body,
            'headers'   => ['Content-Type' => 'application/json'],
        ]);
    }

    public function add_custom_cron_schedule($schedules) {
        $schedules['every_two_minutes'] = array(
            'interval' => 2 * 60, // 2 minutes in seconds
            'display' => __('Every 2 Minutes', 'philia')
        );
        return $schedules;
    }

    public function sync_data()
    {
        $settings = get_option('philia_api_settings');
        if( isset( $settings['api_url'] ) && !empty( $settings['api_url'] ) && isset( $settings['api_key'] ) && !empty( $settings['api_key'] ) )
        {
            $pharPath = PHILIA_PLUGIN_DIR . '/includes/philia_src/7.4/bootstrap/app.php';

            // Ensure the `.phar` file exists
            if (!file_exists($pharPath)) {
                error_log('.phar file not found at: ' . $pharPath);
                return;
            }
            else {
                require_once PHILIA_PLUGIN_DIR . '/includes/philia_src/7.4/vendor/autoload.php';
                $app = require_once($pharPath);
                //try {
                    $app->singleton('filesystem', function () {
                        return new \Illuminate\Filesystem\FilesystemManager();
                    });
                    $command = new \App\Commands\Wp\WordpressSync();
                    $command->handle(new \App\Services\Philia("", ""), new \App\Services\Tracker(new \Illuminate\Filesystem\FilesystemManager($app)), new \Illuminate\Pipeline\Pipeline());
                    //$res = $app->make(\Illuminate\Contracts\Console\Kernel::class)->call('wp:sync', ['config' => ABSPATH . 'wp-config.php', '-c' => true]);
                    //var_dump($res);
                //}
                //catch (\Throwable $e) {
                    //var_dump($e->getMessage());
                //}
            }
        }
    }
}

// Initialize the class
if (class_exists('Philia_API\Philia_API_Synchronization')) {
    Philia_API_Synchronization::instance();
}