<?php
/*
Plugin Name: Philia API Plugin
Description: A plugin to interact with Philia's custom API.
Version: 1.5.1
Author: Philia
Author URI: https://philia.vip
License: MIT
Text Domain: philia
*/

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

define('PHILIA_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
define('PHILIA_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
define('PHILIA_TABLE_PREFIX', 'philia_' );

function philia_load_textdomain() {
    load_plugin_textdomain( 'philia', FALSE, basename( dirname( __FILE__ ) ) . '/languages/' );
}
add_action( 'plugins_loaded', 'philia_load_textdomain' );

// Automatically require all PHP files from the 'includes' folder
$includes_dir = __DIR__ . '/includes/';

require_once($includes_dir. 'class-api-log.php');
require_once($includes_dir. 'class-api-settings.php');
require_once($includes_dir. 'class-core-api.php');
require_once($includes_dir. 'class-user-api.php');
require_once($includes_dir. 'class-product-category-api.php');
require_once($includes_dir. 'class-product-api.php');
require_once($includes_dir. 'class-order-api.php');
//require_once($includes_dir. 'class-api-synchronization.php');

// include cashier
$settings = get_option( 'philia_api_settings' );
if( isset( $settings ) && !empty( $settings ) )
{
    $checked = isset( $settings['enable_cashier'] ) ? (bool) $settings['enable_cashier'] : false;
    if ( $checked ) {
        require_once( $includes_dir . 'cashier/class-cashier-fields.php' );
        require_once( $includes_dir . 'cashier/rest-routes/class-cashier-route.php' );
        require_once( $includes_dir . 'cashier/rest-routes/class-product-category-route.php' );
        require_once( $includes_dir . 'cashier/rest-routes/class-product-route.php' );
        require_once( $includes_dir . 'cashier/rest-routes/class-customer-route.php' );
        require_once( $includes_dir . 'cashier/rest-routes/class-coupon-route.php' );
        require_once( $includes_dir . 'cashier/rest-routes/class-invoice-route.php' );
        require_once( $includes_dir . 'cashier/rest-routes/class-reward-route.php' );
        require_once( $includes_dir . 'cashier/rest-routes/class-account-route.php' );
    }
}

// Function to add the menu page
function philia_api_add_menu_page() {
    // Add top-level menu for Philia API
    add_menu_page(
        __('Philia API Settings', 'philia'), // Page title
        __('Philia', 'philia'), // Menu title
        'manage_options', // Capability
        'philia-api-settings', // Menu slug
        array('Philia_API\Philia_API_Settings', 'philia_api_settings_callback'), // Callback function
        'data:image/svg+xml;base64,' . base64_encode('<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 40.1 39.9" style="enable-background:new 0 0 40.1 39.9;" xml:space="preserve"><g><path class="st0" d="M26.3,13.6L26.3,13.6c0-6.9-5.7-12.6-12.7-12.4C6.7,1.3,1.4,7.2,1.4,14V36c0,1.4,1.1,2.5,2.5,2.5h21.9c6.8,0,12.7-5.4,12.8-12.2C38.8,19.4,33.2,13.6,26.3,13.6z M26.3,32.1c-3.4,0-6.1-2.7-6.1-6.1c0-3.4,2.7-6.1,6.1-6.1c3.4,0,6.1,2.7,6.1,6.1C32.3,29.4,29.6,32.1,26.3,32.1z"/></g></svg>'), // Icon URL or Dashicon class
        2 // Position in the menu
    );

    do_action('philia_menu');
}

// Hook the function to 'admin_menu' action
add_action('admin_menu', 'philia_api_add_menu_page');

register_deactivation_hook(__FILE__, 'my_plugin_deactivation_function');

function my_plugin_deactivation_function() {
    // delete woocommerce api key
    Philia_API\Philia_API_Settings::delete_woocommerce_api_key();
}